@@ -36,7 +36,6 @@ __all__ = ['Reynolds', 'Prandtl', 'Grashof', 'Nusselt', 'Sherwood', 'Rayleigh',
 'head_from_K', 'head_from_P',
 'P_from_head', 'Eotvos']
 
-
 ### Not quite dimensionless groups
 def thermal_diffusivity(k, rho, Cp):
     r'''Calculates thermal diffusivity or `alpha` for a fluid with the given
@@ -427,6 +426,7 @@ def Graetz_heat(V, D, x, rho=None, Cp=None, k=None, alpha=None):
         Gz = \frac{\text{Time for radial heat diffusion in a fluid by conduction}}
         {\text{Time taken by fluid to reach distance x}}
 
+    .. math::
         Gz = \frac{D}{x}RePr
 
     An error is raised if none of the required input sets are provided.
@@ -2162,6 +2162,7 @@ def nu_mu_converter(rho, mu=None, nu=None):
     .. math::
         \nu = \frac{\mu}{\rho}
 
+    .. math::
         \mu = \nu\rho
 
     Parameters
@@ -2505,12 +2506,13 @@ Pr = Prandtl # Synonym
 # but are still desired to be here
 # Taken from scipy/constants/constants.py as in commit 
 # https://github.com/scipy/scipy/commit/4b7d325cd50e8828b06d628e69426a18283dc5b5
+# Also from https://github.com/scipy/scipy/pull/5292
+# by Gillu13  (Gilles Aouizerate)
 # Copyright individual contributors to SciPy
 
-
 # temperature in kelvin
 zero_Celsius = 273.15
-degree_Fahrenheit = 1/1.8 # only for differences
+degree_Fahrenheit = 1.0/1.8 # only for differences
 
 def C2K(C):
     """
@@ -2535,7 +2537,7 @@ def C2K(C):
     --------
     >>> from fluids.core import C2K
     >>> C2K(np.array([-40, 40.0]))
-    array([ 233.15,  313.15])
+    array([233.15, 313.15])
 
     """
     return np.asanyarray(C) + zero_Celsius
@@ -2595,7 +2597,7 @@ def F2C(F):
     array([-40.        ,   4.44444444])
 
     """
-    return (np.asanyarray(F) - 32) / 1.8
+    return (np.asanyarray(F) - 32.0) / 1.8
 
 
 def C2F(C):
@@ -2620,10 +2622,10 @@ def C2F(C):
     --------
     >>> from fluids.core import C2F
     >>> C2F(np.array([-40, 40.0]))
-    array([ -40.,  104.])
+    array([-40., 104.])
 
     """
-    return 1.8 * np.asanyarray(C) + 32
+    return 1.8 * np.asanyarray(C) + 32.0
 
 
 def F2K(F):
@@ -2650,10 +2652,10 @@ def F2K(F):
     --------
     >>> from fluids.core import F2K
     >>> F2K(np.array([-40, 104]))
-    array([ 233.15,  313.15])
+    array([233.15, 313.15])
 
     """
-    return C2K(F2C(np.asanyarray(F)))
+    return (np.asanyarray(F) - 32.0)/1.8 + zero_Celsius
 
 
 def K2F(K):
@@ -2680,7 +2682,281 @@ def K2F(K):
     --------
     >>> from fluids.core import K2F
     >>> K2F(np.array([233.15,  313.15]))
-    array([ -40.,  104.])
+    array([-40., 104.])
 
     """
-    return C2F(K2C(np.asanyarray(K)))
+    return 1.8*(np.asanyarray(K) - zero_Celsius) + 32.0
+
+
+def C2R(C):
+    """
+    Convert Celsius to Rankine
+
+    Parameters
+    ----------
+    C : array_like
+        Celsius temperature(s) to be converted.
+
+    Returns
+    -------
+    Ra : float or array of floats
+        Equivalent Rankine temperature(s).
+
+    Notes
+    -----
+    Computes ``Ra = 1.8 * (C + zero_Celsius)`` where `zero_Celsius` = 273.15,
+    i.e., (the absolute value of) temperature "absolute zero" as measured in
+    Celsius.
+
+    Examples
+    --------
+    >>> from fluids.core import C2R
+    >>> C2R(np.array([-40, 40.0]))
+    array([419.67, 563.67])
+
+    """
+    return 1.8 * (np.asanyarray(C) + zero_Celsius)
+
+
+def K2R(K):
+    """
+    Convert Kelvin to Rankine
+
+    Parameters
+    ----------
+    K : array_like
+        Kelvin temperature(s) to be converted.
+
+    Returns
+    -------
+    Ra : float or array of floats
+        Equivalent Rankine temperature(s).
+
+    Notes
+    -----
+    Computes ``Ra = 1.8 * K``.
+
+    Examples
+    --------
+    >>> from fluids.core import K2R
+    >>> K2R(np.array([273.15, 0.0]))
+    array([491.67,   0.  ])
+
+    """
+    return 1.8 * np.asanyarray(K)
+
+
+def F2R(F):
+    """
+    Convert Fahrenheit to Rankine
+
+    Parameters
+    ----------
+    F : array_like
+        Fahrenheit temperature(s) to be converted.
+
+    Returns
+    -------
+    Ra : float or array of floats
+        Equivalent Rankine temperature(s).
+
+    Notes
+    -----
+    Computes ``Ra = F - 32 + 1.8 * zero_Celsius`` where `zero_Celsius` = 273.15, 
+    i.e., (the absolute value of) temperature "absolute zero" as measured in 
+    Celsius.
+
+    Examples
+    --------
+    >>> from fluids.core import F2R
+    >>> F2R(np.array([100, 0.0]))
+    array([559.67, 459.67])
+
+    """
+    return np.asanyarray(F) - 32.0 + 1.8 * zero_Celsius
+
+
+def R2C(Ra):
+    """
+    Convert Rankine to Celsius
+
+    Parameters
+    ----------
+    Ra : array_like
+        Rankine temperature(s) to be converted.
+
+    Returns
+    -------
+    C : float or array of floats
+        Equivalent Celsius temperature(s).
+
+    Notes
+    -----
+    Computes ``C = Ra / 1.8 - zero_Celsius`` where `zero_Celsius` = 273.15, 
+    i.e., (the absolute value of) temperature "absolute zero" as measured in 
+    Celsius.
+
+    Examples
+    --------
+    >>> from fluids.core import R2C
+    >>> R2C(np.array([459.67, 0.0]))
+    array([ -17.77777778, -273.15      ])
+
+    """
+    return np.asanyarray(Ra) / 1.8 - zero_Celsius
+
+
+def R2K(Ra):
+    """
+    Convert Rankine to Kelvin
+
+    Parameters
+    ----------
+    Ra : array_like
+        Rankine temperature(s) to be converted.
+
+    Returns
+    -------
+    K : float or array of floats
+        Equivalent Kelvin temperature(s).
+
+    Notes
+    -----
+    Computes ``K = Ra / 1.8``.
+
+    Examples
+    --------
+    >>> from fluids.core import R2K
+    >>> R2K(np.array([491.67, 0.0]))
+    array([273.15,   0.  ])
+
+    """
+    return np.asanyarray(Ra) / 1.8
+    
+
+def R2F(Ra):
+    """
+    Convert Rankine to Fahrenheit
+
+    Parameters
+    ----------
+    Ra : array_like
+        Rankine temperature(s) to be converted.
+
+    Returns
+    -------
+    F : float or array of floats
+        Equivalent Fahrenheit temperature(s).
+
+    Notes
+    -----
+    Computes ``F = Ra + 32 - 1.8 * zero_Celsius`` where `zero_Celsius` = 273.15, 
+    i.e., (the absolute value of) temperature "absolute zero" as measured in 
+    Celsius.
+
+    Examples
+    --------
+    >>> from fluids.core import R2F
+    >>> R2F(np.array([491.67, 559.67]))
+    array([ 32., 100.])
+
+    """
+    return np.asanyarray(Ra) - 1.8 * zero_Celsius + 32.0
+
+
+def Engauge_2d_parser(lines, flat=False):
+    '''Not exposed function to read a 2D file generated by engauge-digitizer;
+    for curve fitting.
+    '''
+    z_values = []
+    x_lists = []
+    y_lists = []
+    working_xs = []
+    working_ys = []
+    
+    new_curve = True
+    for line in lines:
+        if line.strip() == '':
+            new_curve = True
+        elif new_curve:
+            z = float(line.split(',')[1])
+            z_values.append(z)
+            if working_xs and working_ys:
+                x_lists.append(working_xs)
+                y_lists.append(working_ys)
+            working_xs = []
+            working_ys = []
+            new_curve = False
+        else:
+            x, y = [float(i) for i in line.strip().split(',')]
+            working_xs.append(x)
+            working_ys.append(y)
+    x_lists.append(working_xs)
+    y_lists.append(working_ys)
+    
+    if flat:
+        all_zs = []
+        all_xs = []
+        all_ys = []
+        for z, xs, ys in zip(z_values, x_lists, y_lists):
+            for x, y in zip(xs, ys):
+                all_zs.append(z)
+                all_xs.append(x)
+                all_ys.append(y)
+        return all_zs, all_xs, all_ys
+
+    return z_values, x_lists, y_lists
+
+
+def horner(coeffs, x):
+    r'''Evaluates a polynomial defined by coefficienfs `coeffs` at a specified
+    scalar `x` value, using the horner method. This is the most efficient 
+    formula to evaluate a polynomial (assuming non-zero coefficients for all
+    terms). This has been added to the `fluids` library because of the need to
+    frequently evaluate polynomials; and `NumPy`'s polyval is actually quite 
+    slow for scalar values.
+    
+    Note that the coefficients are reversed compared to the common form; the
+    first value is the coefficient of the highest-powered x term, and the last
+    value in `coeffs` is the constant offset value.
+
+    Parameters
+    ----------
+    coeffs : iterable[float]
+        Coefficients of polynomial, [-]
+    x : float
+        Point at which to evaluate the polynomial, [-]
+
+    Returns
+    -------
+    val : float
+        The evaluated value of the polynomial, [-]
+
+    Notes
+    -----
+    For maximum speed, provide a list of Python floats and `x` should also be
+    of type `float` to avoid either `NumPy` types or slow python ints. 
+
+    Compare the speed with numpy via:
+        
+    >>> coeffs = np.random.uniform(0, 1, size=15)
+    >>> coeffs_list = coeffs.tolist()
+    
+    %timeit np.polyval(coeffs, 10.0)
+    
+    `np.polyval` takes on the order of 15 us; `horner`, 1 us.
+    
+    Examples
+    --------
+    >>> horner([1.0, 3.0], 2.0)
+    5.0
+
+    References
+    ----------
+    .. [1] "Horner’s Method." Wikipedia, October 6, 2018. 
+    https://en.wikipedia.org/w/index.php?title=Horner%27s_method&oldid=862709437.
+    '''
+    tot = 0.0
+    for c in coeffs:
+        tot = tot*x + c
+    return tot
