@@ -27,7 +27,6 @@ from scipy.interpolate import interp1d, interp2d
 from scipy.constants import hp
 import os
 from io import open
-from pprint import pprint
 
 
 __all__ = ['VFD_efficiency', 'CSA_motor_efficiency', 'motor_efficiency_underloaded',
@@ -35,190 +34,11 @@ __all__ = ['VFD_efficiency', 'CSA_motor_efficiency', 'motor_efficiency_underload
 'specific_speed', 'specific_diameter', 'speed_synchronous', 'nema_sizes',
 'nema_sizes_hp', 'motor_round_size', 'nema_min_P', 'nema_high_P', 'plug_types',
 'voltages_1_phase_residential', 'voltages_3_phase', 'frequencies',
-'residential_power', 'industrial_power', 'current_ideal', 
-'liquid_jet_pump']
+'residential_power', 'industrial_power', 'current_ideal']
 
 folder = os.path.join(os.path.dirname(__file__), 'data')
 
 
-def liquid_jet_pump(rhop, rhos, Km=.15, Kd=0.1, Ks=0.1, Kp=0.0, 
-                     d_nozzle=None, d_mixing=None, d_diffuser=None,
-                     Qp=None, Qs=None, P1=None, P2=None, P5=None,
-                     nozzle_retracted=True):
-    r'''Calculate the remaining variable in a liquid jet pump, using a model
-    presented in [1]_ as well as [2]_, [3]_, and [4]_.
-    
-    .. math::
-        N = \frac{2R + \frac{2 C M^2 R^2}{1-R} - R^2 (1+CM) (1+M) (1 + K_m 
-        + K_d + \alpha^2) - \frac{CM^2R^2}{(1-R)^2} (1+K_s)}
-        {(1+K_p) - 2R - \frac{2CM^2R^2}{1-R} + R^2(1+CM)(1+M)(1+K_m + K_d 
-        + \alpha^2) + (1-j)\left(\frac{CM^2R^2}{({1-R})^2} \right)(1+K_s)}
-        
-        \text{Pressure ratio} = N = \frac{P_5 - P_2}{P_1 - P_5}
-        
-        \text{Volume flow ratio} = M =  \frac{Q_s}{Q_p}
-        
-        \text{Jet pump efficiency} = \eta = M\cdot N = 
-        \frac{Q_s(P_5-P_2)}{Q_p(P_1 - P_5)}
-        
-        R = \frac{A_n}{A_m}
-        
-        C = \frac{\rho_s}{\rho_p}
-    
-    Parameters
-    ----------
-    rhop : float
-        The density of the primary (motive) fluid, [kg/m^3]
-    rhos : float
-        The density of the secondary fluid (drawn from the vacuum chamber),
-        [kg/m^3]
-    Km : float, optional
-        The mixing chamber loss coefficient, [-]
-    Kd : float, optional
-        The diffuser loss coefficient, [-]
-    Ks : float, optional
-        The secondary inlet loss coefficient, [-]
-    Kp : float, optional
-        The primary nozzle loss coefficient, [-]
-    d_nozzle : float, optional
-        The inside diameter of the primary fluid's nozle, [m]
-    d_mixing : float, optional
-        The diameter of the mixing chamber, [m]
-    d_diffuser : float, optional
-        The diameter of the diffuser at its exit, [m]
-    Qp : float, optional
-        The volumetric flow rate of the primary fluid, [m^3/s]
-    Qs : float, optional
-        The volumetric flow rate of the secondary fluid, [m^3/s]
-    P1 : float, optional
-        The pressure of the primary fluid entering its nozzle, [Pa]
-    P2 : float, optional
-        The pressure of the secondary fluid at the entry of the ejector, [Pa]
-    P5 : float, optional
-        The pressure at the exit of the diffuser, [Pa]
-    nozzle_retracted : bool, optional
-        Whether or not the primary nozzle's exit is before the mixing chamber,
-        or somewhat inside it, [-]
-        
-    Returns
-    -------
-    solution : dict
-        Dictionary of calculated parameters, [-]
-
-    Notes
-    -----
-    
-    The assumptions of the model are:
-        
-    * The flows are one dimensional except in the mixing chamber.
-    * The mixing chamber has constant cross-sectional area.
-    * The mixing happens entirely in the mixing chamber, prior to entry into
-      the diffuser.
-    * The primary nozzle is in a straight line with the middle of the mixing 
-      chamber.
-    * Both fluids are incompressible, and have no excess volume on mixing.
-    * Primary and secondary flows both enter the mixing throat with their
-      own uniform velocity distribution; the mixed stream leaves with a uniform
-      velocity profile.
-    * If the secondary fluid is a gas, it undergoes isothermal compression in
-      the throat and diffuser. 
-    * If the secondary fluid is a gas or contains a bubbly gas, it is
-      homogeneously distributed in a continuous liquid phase.
-    * Heat transfer between the fluids is negligible - there is no change in
-      density due to temperature changes
-    * The change in the solubility of a disolved gas, if there is one, is
-      negigibly changed by temperature or pressure changes.
-
-    Examples
-    --------
-    >>> pprint(liquid_jet_pump(rhop=998., rhos=1098., Km=.186, Kd=0.12, Ks=0.11, 
-    ... Kp=0.04, d_nozzle=0.0223, d_mixing=0.045, Qs=0.01, Qp=.01, P2=133600, 
-    ... P5=200E3, nozzle_retracted=False))
-    {'M': 1.0,
-     'N': 0.2938665390183575,
-     'P1': 425952.91121542786,
-     'P2': 133600,
-     'P5': 200000.0,
-     'Qp': 0.01,
-     'Qs': 0.01,
-     'R': 0.24557530864197535,
-     'alpha': 1e-06,
-     'd_diffuser': 45.0,
-     'd_mixing': 0.045,
-     'd_nozzle': 0.0223,
-     'efficiency': 0.2938665390183575}
-
-    References
-    ----------
-    .. [1] Karassik, Igor J., Joseph P. Messina, Paul Cooper, and Charles C. 
-       Heald. Pump Handbook. 4th edition. New York: McGraw-Hill Education, 2007.
-    .. [2] Winoto S. H., Li H., and Shah D. A. "Efficiency of Jet Pumps." 
-       Journal of Hydraulic Engineering 126, no. 2 (February 1, 2000): 150-56. 
-       https://doi.org/10.1061/(ASCE)0733-9429(2000)126:2(150).
-    .. [3] Elmore, Emily, Khalid Al-Mutairi, Bilal Hussain, and A. Sherif
-       El-Gizawy. "Development of Analytical Model for Predicting Dual-Phase
-       Ejector Performance," November 11, 2016, V007T09A013.
-    .. [4] Ejectors and Jet Pumps. Design and Performance for Incompressible 
-       Liquid Flow. 85032. ESDU International PLC, 1985.
-    '''
-    C = rhos/rhop
-    if nozzle_retracted:
-        j = 0.0
-    else:
-        j = 1.0
-    # The diffuser diameter has little effect - it can be specified, and the 
-    # results will be a little more accurate - or it can be omitted and it 
-    # will be set to a large value so it is ignored in the calculations.
-    if d_diffuser is None:
-        if d_mixing is not None:
-            d_diffuser = d_mixing*1E3
-        elif d_nozzle is not None:
-            d_diffuser = d_nozzle*1E3
-            
-    unknowns = sum(i is not None for i in (d_nozzle, d_mixing, Qs, Qp, P1, P2, P5))
-    if unknowns < 1:
-        raise Exception('Too many unknowns')
-    elif unknowns < 1:
-        raise Exception('Overspecified')
-    if P1 is None or P2 is None or P5 is None:
-        # Direct solution - easy
-        R = d_nozzle**2/d_mixing**2
-        alpha = d_mixing**2/d_diffuser**2
-        M = Qs/Qp
-        
-        M2, R2, alpha2 = M*M, R*R, alpha*alpha
-        num = 2.0*R + 2*C*M2*R2/(1.0 - R)
-        num -= R2*(1.0 + C*M)*(1.0 + M)*(1.0 + Km + Kd + alpha2)
-        num -= C*M2*R2/(1.0 - R)**2*(1.0 + Ks)
-        
-        den = (1.0 + Kp) - 2.0*R - 2.0*C*M2*R2/(1.0 - R)
-        den += R2*(1.0 + C*M)*(1.0 + M)*(1.0 + Km + Kd + alpha2)
-        den += (1.0 - j)*(C*M2/((1.0 - R)/R)**2)*(1.0 - Ks)
-        N = num/den
-        if P1 is None:
-            P1 = (-P2 + P5*N + P5)/N
-        elif P2 is None:
-            P2 = -P1*N + P5*N + P5
-        elif P5 is None:
-            P5 = (P1*N + P2)/(N + 1.0)
-            
-    solution = {}
-    solution['P1'] = P1
-    solution['P2'] = P2
-    solution['P5'] = P5
-    solution['d_nozzle'] = d_nozzle
-    solution['d_mixing'] = d_mixing
-    solution['d_diffuser'] = d_diffuser
-    solution['Qs'] = Qs
-    solution['Qp'] = Qp
-    solution['N'] = N
-    solution['M'] = M
-    solution['R'] = R
-    solution['alpha'] = alpha
-    solution['efficiency'] = M*N
-    return solution
-
-
 def Corripio_pump_efficiency(Q):
     r'''Estimates pump efficiency using the method in Corripio (1982)
     as shown in [1]_ and originally in [2]_. Estimation only
@@ -414,7 +234,7 @@ def motor_round_size(P):
     for P_actual in nema_sizes:
         if P_actual >= P:
             return P_actual
-    raise Exception('Required power is larger than can be provided with one valve')
+    raise Exception('Required power is larger than can be provided with one motor')
 
 
 nema_high_P = [1, 1.5, 2, 3, 4, 5, 5.5, 7.5, 10, 15, 20, 25, 30, 40, 50, 60, 75, 100, 125, 150, 175, 200]
@@ -971,7 +791,8 @@ fan_centrifugal_backward_efficiencies = {'FMEG35': FMEG35,
                                          'FMEG74': FMEG74,
                                          'FMEG76': FMEG76}
 
-FMEG_cross_flow_powers = [130.0, 300.0, 500.0, 800.0, 1000.0, 2000.0, 3000.0, 4000.0, 5000.0, 8000.0, 10000.0, 16000.0, 22000.0]
+FMEG_cross_flow_powers = [130.0, 300.0, 500.0, 800.0, 1000.0, 2000.0, 3000.0,
+                          4000.0, 5000.0, 8000.0, 10000.0, 16000.0, 22000.0]
 
 FMEG08 = [3, 4, 4.6, 5.1, 5.4, 6.2, 6.7, 7, 7.2, 7.8, 8, 8, 8]
 FMEG11 = [6, 7, 7.6, 8.1, 8.4, 9.2, 9.7, 10, 10.2, 10.8, 11, 11, 11]
